@@ -59,6 +59,7 @@ class AudioElement(VideoBase):
         self.is_muted: bool = False
         self.loop_until_scene_end: bool = False
         self.original_duration: float = 0.0
+        self._duration_overridden: bool = False
         self._load_audio_info()
         # 初期化時にサイズを計算（オーディオは視覚的要素がないため0）
         self.calculate_size()
@@ -173,6 +174,10 @@ class AudioElement(VideoBase):
         self.loop_until_scene_end = loop
 
         return self
+
+    def set_duration(self, duration: float) -> 'AudioElement':
+        self._duration_overridden = True
+        return super().set_duration(duration)
     
     def update_duration_for_scene(self, scene_duration: float) -> None:
         """Update duration to match scene duration when in BGM loop mode.
@@ -292,4 +297,4 @@ class AudioElement(VideoBase):
         on the specific audio library being used.
         """
         # オーディオ要素用のクリーンアップ
-        pass
\ No newline at end of file
+        pass
