@@ -169,6 +169,8 @@ class MasterScene:
         from .audio_element import AudioElement
         for audio_element in self.audio_elements:
             if isinstance(audio_element, AudioElement) and audio_element.loop_until_scene_end:
+                if getattr(audio_element, '_duration_overridden', False):
+                    continue
                 # マスターシーン全体の長さまでBGMを拡張
                 if self.total_duration > audio_element.duration:
                     audio_element.duration = self.total_duration
@@ -413,18 +415,6 @@ class MasterScene:
                 print(f"  WARNING: Audio starts before scene start")
             
             # BGMモードでループが必要な場合は複数回入力を追加
-            if getattr(audio_element, 'loop_until_scene_end', False) and audio_element.duration > audio_element.original_duration:
-                # 必要なループ回数を計算
-                loop_count = int((audio_element.duration / audio_element.original_duration) + 0.99)
-                
-                # 同じファイルを複数回入力として追加
-                for i in range(loop_count):
-                    cmd.extend(['-i', audio_element.audio_path])
-                
-            else:
-                # 通常の単一入力
-                cmd.extend(['-i', audio_element.audio_path])
-            
             valid_audio_files.append(audio_element)
         
         if not valid_audio_files:
@@ -437,65 +427,74 @@ class MasterScene:
             audio_element = valid_audio_files[0]
             volume = audio_element.volume if hasattr(audio_element, 'volume') else 1.0
             is_muted = getattr(audio_element, 'is_muted', False)
+            end_time = min(self.total_duration, audio_element.start_time + audio_element.duration)
+            loop_count = 1
 
             # ミュート状態の場合は音量を0にする
             if is_muted:
                 volume = 0.0
-            
+
             # BGMのループが必要な場合
             if getattr(audio_element, 'loop_until_scene_end', False) and audio_element.duration > audio_element.original_duration:
                 # 複数の入力ストリームを連結してループを作成
                 loop_count = int((audio_element.duration / audio_element.original_duration) + 0.99)
+                for _ in range(loop_count):
+                    cmd.extend(['-i', audio_element.audio_path])
 
                 # 複数のストリームを連結
                 input_streams = []
                 for i in range(1, loop_count + 1):  # 1から開始（0はビデオ）
                     input_streams.append(f"[{i}:a]")
-                
+
                 # 連結フィルター
                 concat_filter = ''.join(input_streams) + f"concat=n={loop_count}:v=0:a=1[looped];"
-                
+
                 # 遅延処理
                 start_time = audio_element.start_time
                 filter_chain = "[looped]"
                 if start_time > 0:
                     delay_ms = int(start_time * 1000)
                     filter_chain += f"adelay={delay_ms}|{delay_ms},"
-                
+
                 # 音量調整と時間制限
-                filter_chain += f"volume={volume},atrim=end={self.total_duration}"
-                
+                filter_chain += f"volume={volume},atrim=end={end_time}"
+
                 full_filter = concat_filter + filter_chain
                 cmd.extend(['-filter_complex', full_filter, '-c:v', 'copy', '-c:a', 'aac', 
                            '-t', str(self.total_duration), final_output])
             else:
                 # 単一ファイル、ループなしの場合
                 filter_chain = ""
+                cmd.extend(['-i', audio_element.audio_path])
                 
                 # 遅延処理
                 start_time = audio_element.start_time
                 if start_time > 0:
                     delay_ms = int(start_time * 1000)
                     filter_chain += f"adelay={delay_ms}|{delay_ms},"
-                
+
                 # 音量調整と時間制限
-                filter_chain += f"volume={volume},atrim=end={self.total_duration}"
-                
+                filter_chain += f"volume={volume},atrim=end={end_time}"
+
                 cmd.extend(['-filter:a', filter_chain, '-c:v', 'copy', '-c:a', 'aac', 
                            '-t', str(self.total_duration), final_output])
         else:
             # オーディオストリームをミキシングするfilter_complexを構築（adelayでタイミング制御）
+            for audio_element in valid_audio_files:
+                cmd.extend(['-i', audio_element.audio_path])
+            
             audio_inputs = []
             for i, audio_element in enumerate(valid_audio_files, 1):  # index 1から開始（index 0はビデオ）
                 # 各オーディオストリームに対してvolume、delay、duration制限を適用
                 volume = audio_element.volume if hasattr(audio_element, 'volume') else 1.0
                 start_time = audio_element.start_time
                 delay_ms = int(start_time * 1000)  # milliseconds for adelay
+                end_time = min(self.total_duration, audio_element.start_time + audio_element.duration)
 
                 # ミュート状態の場合は音量を0にする
                 if getattr(audio_element, 'is_muted', False):
                     volume = 0.0
-                
+
                 # フィルターチェーンを構築
                 filter_chain = f"[{i}:a]"
                 
@@ -508,21 +507,21 @@ class MasterScene:
                 # 遅延を適用（0秒の場合はスキップ）
                 if delay_ms > 0:
                     filter_chain += f"adelay={delay_ms}|{delay_ms},"  # ステレオの場合両チャンネルに適用
-                
+
                 # 音量調整を適用
                 filter_chain += f"volume={volume}"
-                
+
                 # 最終的な時間制限を適用（全体の動画時間を超えないように）
                 if getattr(audio_element, 'loop_until_scene_end', False):
-                    filter_chain += f",atrim=end={self.total_duration}"
+                    filter_chain += f",atrim=end={end_time}"
                 else:
-                    pass
-                
+                    filter_chain += f",atrim=end={end_time}"
+
                 audio_inputs.append(f"{filter_chain}[a{i}]")
             
             # 全てのオーディオストリームをミキシング（正規化を無効にして音量を保持）
             mix_inputs = ''.join([f"[a{i}]" for i in range(1, len(valid_audio_files) + 1)])
-            filter_complex = ';'.join(audio_inputs) + f";{mix_inputs}amix=inputs={len(valid_audio_files)}:normalize=0[aout]"
+            filter_complex = ';'.join(audio_inputs) + f";{mix_inputs}amix=inputs={len(valid_audio_files)}:normalize=0:duration=longest[aout]"
             
             cmd.extend(['-filter_complex', filter_complex, '-map', '0:v', '-map', '[aout]', 
                        '-c:v', 'copy', '-c:a', 'aac', '-t', str(self.total_duration), final_output])
