@@ -264,6 +264,9 @@ class TextElement(VideoBase):
         # 背景と枠線を適用
         img = self._apply_border_and_background_to_image(img)
         
+        # ブラー効果を適用
+        img = self._apply_blur_to_image(img)
+        
         # パディングと角丸を元に戻す
         self.padding = original_padding
         self.corner_radius = original_corner_radius
@@ -407,6 +410,12 @@ class TextElement(VideoBase):
         if hasattr(self, 'rotation') and self.rotation != 0:
             glRotatef(self.rotation, 0, 0, 1)
         
+        # フリップ変換を適用
+        flip_x = -1.0 if getattr(self, 'flip_horizontal', False) else 1.0
+        flip_y = -1.0 if getattr(self, 'flip_vertical', False) else 1.0
+        if flip_x != 1.0 or flip_y != 1.0:
+            glScalef(flip_x, flip_y, 1.0)
+        
         # スケールを適用
         if hasattr(self, 'scale') and self.scale != 1.0:
             glScalef(self.scale, self.scale, 1.0)
